:orphan:

.. _gallery:




.. raw:: html

    <div class="sphx-glr-thumbnails">

.. thumbnail-parent-div-open

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrate how to use the project_points function to project 3D world_points to 2D image_points using a specified camera model, which includes the intrinsic, extrinsic and distortion transformations.">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_project_points_thumb.png
    :alt:

  :doc:`/_gallery/project_points`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Projecting 3D points to 2D image points with project_points</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrate how to use the distort_image function to apply a distortion to an image using a specified camera model, which includes the intrinsic and distortion transformations.">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_distorting_image_thumb.png
    :alt:

  :doc:`/_gallery/distorting_image`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Distorting an image with distort_image and undistort_image</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrate how to use the compute_optical_flow function to compute the optical flow between two images.">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_optical_flow_thumb.png
    :alt:

  :doc:`/_gallery/optical_flow`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Computing optical flow between two images</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example illustrate how to use the optimize_parameters_trf function to optimize the distortion parameters of a camera model, which includes the intrinsic and distortion transformations.">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_optimize_parameters_thumb.png
    :alt:

  :doc:`/_gallery/optimize_parameters`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Optimizing distortion parameters with least squares</div>
    </div>


.. thumbnail-parent-div-close

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /_gallery/project_points
   /_gallery/distorting_image
   /_gallery/optical_flow
   /_gallery/optimize_parameters


.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-gallery

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download all examples in Python source code: _gallery_python.zip </_gallery/_gallery_python.zip>`

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download all examples in Jupyter notebooks: _gallery_jupyter.zip </_gallery/_gallery_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
